
#####################################################
# DO NOT MODIFY
# This file is used to define the remote assets
#####################################################
        
js_dist = [
  {
    "relative_package_path": "assets/plugin.js",
    "external_url": "https://cdn.jsdelivr.net/npm/luckysheet/dist/plugins/js/plugin.js",
    "namespace": "dash_luckysheet",
    "dynamic": False
  },
  {
    "relative_package_path": "assets/luckysheet.umd.js",
    "external_url": "https://cdn.jsdelivr.net/npm/luckysheet/dist/luckysheet.umd.js",
    "namespace": "dash_luckysheet",
    "dynamic": False
  },
  {
    "relative_package_path": "assets/luckysheet.umd.js.map",
    "external_url": "https://cdn.jsdelivr.net/npm/luckysheet/dist/luckysheet.umd.js.map",
    "namespace": "dash_luckysheet",
    "dynamic": True
  },
  {
    "relative_package_path": "assets/luckyexcel.umd.js",
    "external_url": "https://cdn.jsdelivr.net/npm/luckyexcel/dist/luckyexcel.umd.js",
    "namespace": "dash_luckysheet",
    "dynamic": False
  },
  {
    "relative_package_path": "assets/luckyexcel.umd.js.map",
    "external_url": "https://cdn.jsdelivr.net/npm/luckyexcel/dist/luckyexcel.umd.js.map",
    "namespace": "dash_luckysheet",
    "dynamic": True
  },
  {
    "relative_package_path": "assets/exceljs.min.js",
    "external_url": "https://cdn.jsdelivr.net/npm/exceljs/dist/exceljs.min.js",
    "namespace": "dash_luckysheet",
    "dynamic": False
  },
  {
    "relative_package_path": "assets/exceljs.min.js.map",
    "external_url": "https://cdn.jsdelivr.net/npm/exceljs/dist/exceljs.min.js.map",
    "namespace": "dash_luckysheet",
    "dynamic": True
  }
]

css_dist = [
  {
    "relative_package_path": "assets/pluginsCss.css",
    "external_url": "https://cdn.jsdelivr.net/npm/luckysheet/dist/plugins/css/pluginsCss.css",
    "namespace": "dash_luckysheet",
    "dynamic": False
  },
  {
    "relative_package_path": "assets/plugins.css",
    "external_url": "https://cdn.jsdelivr.net/npm/luckysheet/dist/plugins/plugins.css",
    "namespace": "dash_luckysheet",
    "dynamic": False
  },
  {
    "relative_package_path": "assets/luckysheet.css",
    "external_url": "https://cdn.jsdelivr.net/npm/luckysheet/dist/css/luckysheet.css",
    "namespace": "dash_luckysheet",
    "dynamic": False
  },
  {
    "relative_package_path": "assets/iconfont.css",
    "external_url": "https://cdn.jsdelivr.net/npm/luckysheet/dist/assets/iconfont/iconfont.css",
    "namespace": "dash_luckysheet",
    "dynamic": False
  },
  {
    "relative_package_path": "assets/loading.gif",
    "external_url": "https://raw.githubusercontent.com/mengshukeji/LuckysheetDemo/master/css/loading.gif",
    "namespace": "dash_luckysheet",
    "dynamic": True
  },
  {
    "relative_package_path": "assets/EwaAntH.gif",
    "external_url": "https://raw.githubusercontent.com/mengshukeji/LuckysheetDemo/master/css/EwaAntH.gif",
    "namespace": "dash_luckysheet",
    "dynamic": True
  },
  {
    "relative_package_path": "assets/EwaAntV.gif",
    "external_url": "https://raw.githubusercontent.com/mengshukeji/LuckysheetDemo/master/css/EwaAntV.gif",
    "namespace": "dash_luckysheet",
    "dynamic": True
  },
  {
    "relative_package_path": "assets/waffle_sprite.png",
    "external_url": "https://mengshukeji.github.io/LuckysheetDemo/css/waffle_sprite.png",
    "namespace": "dash_luckysheet",
    "dynamic": True
  },
  {
    "relative_package_path": "assets/icon_dropCell.png",
    "external_url": "https://raw.githubusercontent.com/mengshukeji/LuckysheetDemo/master/plugins/images/icon_dropCell.png",
    "namespace": "dash_luckysheet",
    "dynamic": True
  },
  {
    "relative_package_path": "fonts/fontawesome-webfont.woff2",
    "external_url": "https://github.com/h5p/font-awesome/raw/master/fontawesome-webfont.woff2",
    "namespace": "dash_luckysheet",
    "dynamic": True
  },
  {
    "relative_package_path": "fonts/fontawesome-webfont.woff",
    "external_url": "https://github.com/h5p/font-awesome/raw/master/fontawesome-webfont.woff",
    "namespace": "dash_luckysheet",
    "dynamic": True
  },
  {
    "relative_package_path": "fonts/fontawesome-webfont.ttf",
    "external_url": "https://github.com/h5p/font-awesome/raw/master/fontawesome-webfont.ttf",
    "namespace": "dash_luckysheet",
    "dynamic": True
  }
]


import pandas as _pd

def get_luckysheet(df: _pd.DataFrame, name="Sheet1"):
    return {
        "name": name,
        "color": "",
        "status": 1,
        "order": 0,
        "config": {
            "rowlen": {},
            "customHeight": {},
            "borderInfo": [
                {
                    "rangeType": "range",
                    "borderType": "border-all",
                    "color": "#000",
                    "style": "1",
                    "range": [
                        {
                            "row": [
                                0,
                                len(df),
                            ],
                            "column": [
                                0,
                                len(df.columns)-1
                            ],
                        }
                    ]
                },
                {
                    "rangeType": "range",
                    "borderType": "border-all",
                    "color": "#000",
                    "style": "8",
                    "range": [
                        {
                            "row": [
                                0,
                                0
                            ],
                            "column": [
                                0,
                                len(df.columns)-1
                            ],

                        }
                    ]
                }]

        },
        "filter_select": {
            "row": [
                0,
                len(df),
            ],
            "column": [
                0,
                len(df.columns)-1
            ]},
        "data": [[{
            "m": el,
            "ct": {
                "fa": "General",
                "t": "g"
            },
            "v": el,
            "bl": 1,
            "fs": "11"
        } for el in df.columns], *df.values.tolist()],
        "row": len(df)+1,
        "column": len(df.columns),
        "scrollLeft": 0,
        "scrollTop": 0,
        "frozen": {
            "type": "row"
        },

    }



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Luckysheet(Component):
    """A Luckysheet component.
ExampleComponent is an example component.
It takes a property, `label`, and
displays it.
It renders an input with the property `value`
which is editable by the user.

Keyword arguments:

- id (string; required):
    The ID used to identify this component in Dash callbacks.

- data (boolean | number | string | dict | list; optional):
    data shown by the component.

- style (boolean | number | string | dict | list; optional):
    additional style options.

- xlsx (boolean | number | string | dict | list; optional):
    data of an xlsx file."""
    @_explicitize_args
    def __init__(self, id=Component.REQUIRED, data=Component.UNDEFINED, xlsx=Component.UNDEFINED, style=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'data', 'style', 'xlsx']
        self._type = 'Luckysheet'
        self._namespace = 'dash_luckysheet'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'data', 'style', 'xlsx']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in ['id']:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(Luckysheet, self).__init__(**args)



import json
import os
from setuptools import setup


with open('package.json') as f:
    package = json.load(f)

package_name = package["name"].replace(" ", "_").replace("-", "_")

setup(
    name=package_name,
    version=package["version"],
    author=package['author'],
    packages=[
        package_name,
    ],
    include_package_data=True,
    license=package['license'],
    description=package.get('description', package_name),
    install_requires=[],
    classifiers=[
        'Framework :: Dash',
    ],
)
